# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - AddLinkToPage

    Add a link using a form in the page, getting details of the linked document
    and inserting them with the link itself.

    @copyright: 2010 Paul Boddie <paul@boddie.org.uk>
    @license: GNU GPL, see COPYING for details.
"""

Dependencies = ["pages"]

from MoinMoin import wikiutil

# Macro functions.

def execute(macro, args):

    """
    Execute the 'macro' with the given 'args': 
    """

    request = macro.request
    formatter = macro.formatter
    page = formatter.page
    _ = macro._

    # Interpret the arguments.

    try:
        parsed_args = args and wikiutil.parse_quoted_separated(args, name_value=False) or []
    except AttributeError:
        parsed_args = args.split(",")

    parsed_args = [arg for arg in parsed_args if arg]

    # The macro's identifier should always appear first.

    try:
        identifier = parsed_args[0]
    except IndexError, exc:
        return macro.format_error(exc)

    # Look for keywords determining the action of the macro.

    insert_before = "before" in parsed_args[1:] or not ("after" in parsed_args[1:])

    # Show the fields for link submission.

    d = {
        "script_name" : request.getScriptname(),
        "page_url" : wikiutil.quoteWikinameURL(page.page_name),
        "identifier" : wikiutil.escape(identifier, 1),
        "insert_before" : insert_before and "true" or "",
        "submit_label" : wikiutil.escape(_("Add link"))
        }

    html = '''
<form class="macro" method="POST" action="%(script_name)s/%(page_url)s">
  <input type="hidden" name="action" value="AddLinkToPage" />
  <input type="hidden" name="identifier" value="%(identifier)s" />
  <input type="hidden" name="insert_before" value="%(insert_before)s" />
  <div>
    <input type="text" name="link" />
    <input type="submit" value="%(submit_label)s" />
  </div>
</form>''' % d

    return formatter.rawHTML(html)

# vim: tabstop=4 expandtab shiftwidth=4
